@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.112 $
- * $Date: 1996/01/04 18:28:53 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/gopher/gopher.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.7 $
+ * $Date: 2002/01/08 21:35:49 $
+ * $Source: /var/cvs/gopher/gopher/gopher.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,54 @@
  *********************************************************************
  * Revision History:
  * $Log: gopher.c,v $
+ * Revision 1.7  2002/01/08 21:35:49  jgoerzen
+ * Many changes:
+ *  Revved the version number
+ *  updated greeting
+ *  updated copyright notices
+ *
+ * Revision 1.6  2002/01/08 20:57:26  jgoerzen
+ * Small logic error fixed
+ *
+ * Revision 1.5  2002/01/08 20:30:35  jgoerzen
+ *     * gopher.c: Modified to use HAVE_STRERROR
+ *
+ * Revision 1.4  2002/01/08 17:36:14  jgoerzen
+ * Finally builds!
+ *
+ * Changes:
+ *
+ *   * config.h.in: rebuilt by autoheader
+ *
+ *   * configure: rebuilt by autoconf
+ *
+ *   * configure.in:
+ *     * Added REGEXLIBS test for NetBSD -- look for re_comp in -lcompat
+ *     * Added checkes for term.h, re_comp.h, regex.h
+ *
+ *   * gopher/ourutils.c, gopher/CURcurses.c: Use term.h check
+ *
+ *   * gopher/Makefile.in, gopherd/Makefile.in, gophfilt/Makefile.in:
+ *     * Use REGEXLIBS
+ *
+ *   * gopher/globals.h, gopher/gopher.c: Remove sys_errlist
+ *
+ *   * object/GSgopherobj.c: Removed <regex.h> #include, now use
+ *     "Regex.h" that has proper regex determining logic
+ *
+ *   * object/Regex.h: Moved regex.h include to here.  Make it conditional
+ *     based on configure test.  Add conditional re_comp.h include.
+ *
+ * Revision 1.3  2000/12/27 21:22:46  s2mdalle
+ * Added a few #include's to get at prototypes for implicitly defined
+ * functions
+ *
+ * Revision 1.2  2000/08/19 01:18:16  jgoerzen
+ * fix sys_errlist
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.112  1996/01/04  18:28:53  lindner
  * Updates for autoconf
  *
@@ -448,6 +496,10 @@ static	CursesObj	*LangScreen = NULL;
 #include "Malloc.h"
 #include "patchlevel.h"
 
+#ifdef HAVE_TIME_H
+#  include <time.h>
+#endif /* HAVE_TIME_H */
+
 void describe_gopher(char *banner, GopherStruct *ZeGopher, FILE *gripefile);
 extern int  twirl(void);
 
@@ -1181,8 +1233,10 @@ popgopher(GopherDirObj **ZeDir)
 #include <perror.h>
 #else
 extern int h_errno;
+#ifndef HAVE_STRERROR
 extern int sys_nerr;
 extern char *sys_errlist[];
+#endif
 extern int  errno;
 #endif
 
@@ -1214,11 +1268,13 @@ void check_sock(int sockfd, char *host, int port)
 #else
 #  ifdef __DECC
 	       if (errno > 0 && errno <= 65) {
+#  elsif defined(HAVE_STRERROR)
+               if (1) {
 #  else
 	       if (errno > 0 && errno <= sys_nerr) {
 #  endif
 		    sprintf(DispString2, Gtxt("Connection failed: %s.",78),
-#ifdef VMS
+#if defined(VMS) || defined(HAVE_STRERROR)
 			    strerror(errno));
 #else
 		    sys_errlist[errno]);
@@ -1739,9 +1795,11 @@ main(int argc, char **argv)
      
      /** Should generalize this to >2 hosts .... Sigh... ***/
      GSsetHost (RootGophers[0], CLIENT1_HOST);
+     GSsetPath (RootGophers[0], CLIENT1_PATH);
      GSsetPort (RootGophers[0], CLIENT1_PORT);
 
      GSsetHost (RootGophers[1], CLIENT2_HOST);
+     GSsetHost (RootGophers[1], CLIENT2_PATH);
      GSsetPort (RootGophers[1], CLIENT2_PORT);
 
      if (CLIENT2_PORT == 0)
